#
# spec file for package SAPHanaSR-angi
#
# Copyright (c) 2013-2014 SUSE Linux Products GmbH, Nuernberg, Germany.
# Copyright (c) 2014-2016 SUSE Linux GmbH, Nuernberg, Germany.
# Copyright (c) 2017-2025 SUSE LLC.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/

Name:           SAPHanaSR-angi
VCS: https://src.suse.de/SLFO-pool/SAPHanaSR-angi#cfaed8d079b4e9335949354bf125e0199551ac1fdf73561f3e1b39dacc3d8633
License:        GPL-2.0
Group:          Productivity/Clustering/HA
AutoReqProv:    on
Summary:        Resource agents to control the HANA database in system replication setup
Version:        1.2.10
Release:        160000.1.2
Url:            https://www.suse.com/c/fail-safe-operation-of-sap-hana-suse-extends-its-high-availability-solution/

Conflicts:      SAPHanaSR SAPHanaSR-ScaleOut SAPHanaSR-doc SAPHanaSR-ScaleOut-doc
BuildArch:      noarch

Source0:        %{name}-%{version}.tgz

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

Requires:       pacemaker > 2.1.2
Requires:       resource-agents
Requires:       perl

# Require crmsh-scripts for the HAWK2 wizards
Requires:       crmsh >= 4.4.0
Requires:       crmsh-scripts >= 4.4.0
Requires:       python3
Requires:       /usr/bin/xmllint
%if 0%{?suse_version} >= 1600
Requires:       /usr/bin/sudo
Requires:       /usr/bin/logger
%endif
BuildRequires:  resource-agents >= 4.1.0
BuildRequires:  crmsh
BuildRequires:  crmsh-scripts

%description
SAPHanaSR-angi is "SAP HANA SR - An Next Generation Interface" for SUSE high availabilty clusters to manage SAP HANA databases with system replication.

The current version of SAPHanaSR-angi is targeting SAP HANA SR scale-up and scale-out setups.

CIB attributes are not backward compatible between SAPHanaSR-angi and SAPHanaSR. Nevertheless, SAPHanaSR and SAPHanaSR-ScaleOut can be upgraded to SAPHanaSR-angi by following the documented procedure.

For SAP HANA Databases in System Replication only the listed scenarios at https://documentation.suse.com/sles-sap/sap-ha-support/html/sap-ha-support/article-sap-ha-support.html are supported. For any scenario not matching the scenarios named or referenced in our setup guides please contact SUSE services.

The following SUSE blog series gives a good overview about running SAP HANA in System Replication in the SUSE cluster:
https://www.suse.com/c/tag/towardszerodowntime/

Authors:
--------
    Angela Briel
    Fabian Herschel
    Lars Pinne

%prep
tar xf %{S:0}

%build
gzip man/*

%install
mkdir -p %{buildroot}/usr/bin
mkdir -p %{buildroot}%{_docdir}/%{name}
mkdir -p %{buildroot}/usr/share/%{name}/icons
mkdir -p %{buildroot}/usr/share/%{name}/samples
mkdir -p %{buildroot}/usr/share/%{name}/samples/crm_cfg/angi-ScaleUp
mkdir -p %{buildroot}/usr/lib/ocf/resource.d/suse
mkdir -p %{buildroot}/usr/lib/%{name}
mkdir -p %{buildroot}%{_mandir}/man7
mkdir -p %{buildroot}%{_mandir}/man8

# resource agents (ra) and ra-libraries
mkdir -p %{buildroot}/usr/lib/%{name}
install -m 0755 ra/SAPHana* %{buildroot}/usr/lib/ocf/resource.d/suse/
install -m 0644 ra/saphana-*-lib %{buildroot}/usr/lib/%{name}

# HA/DR hook provider
install -m 0644 srHook/susHanaSR.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susTkOver.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susCostOpt.py %{buildroot}/usr/share/%{name}/
install -m 0644 srHook/susChkSrv.py %{buildroot}/usr/share/%{name}/
install -m 0444 srHook/global.ini_* %{buildroot}/usr/share/%{name}/samples

# alert manager
install -m 0755 alert/SAPHanaSR-alert-fencing %{buildroot}/usr/bin

# crm config templates
install -m 0644 crm_cfg/angi-ScaleUp/[0-9]*_* %{buildroot}/usr/share/%{name}/samples/crm_cfg/angi-ScaleUp

# icons for SAPHanaSR-monitor
install -m 0444 icons/* %{buildroot}/usr/share/%{name}/icons

# manual pages
install -m 0444 man/*.7.gz %{buildroot}%{_mandir}/man7
install -m 0444 man/*.8.gz %{buildroot}%{_mandir}/man8

# auxiliary python library and tools
install -m 0555 tools/SAPHanaSR-showAttr %{buildroot}/usr/bin
install -m 0555 tools/SAPHanaSR-replay-archive %{buildroot}/usr/bin
install -m 0555 tools/SAPHanaSR-hookHelper %{buildroot}/usr/bin
install -m 0555 tools/SAPHanaSR-manageProvider %{buildroot}/usr/bin
install -m 0555 tools/SAPHanaSR-upgrade-to-angi-demo %{buildroot}/usr/share/%{name}/samples
install -m 0444 tools/saphana_sr_tools.py %{buildroot}/usr/lib/%{name}

%files
%defattr(-,root,root)
%dir /usr/lib/ocf
%dir /usr/lib/ocf/resource.d
%dir /usr/lib/ocf/resource.d/suse
/usr/lib/ocf/resource.d/suse/*
/usr/share/%{name}
%dir /usr/lib/%{name}
/usr/lib/%{name}/saphana-*-lib
/usr/lib/%{name}/saphana_sr_*.py
/usr/bin/SAPHanaSR-showAttr
/usr/bin/SAPHanaSR-replay-archive
/usr/bin/SAPHanaSR-hookHelper
/usr/bin/SAPHanaSR-manageProvider
/usr/bin/SAPHanaSR-alert-fencing

%license LICENSE
%dir %{_docdir}/%{name}
%doc README.md
%doc %{_mandir}/man7/*
%doc %{_mandir}/man8/*

%changelog
* Fri Mar  7 2025 abriel@suse.com
- Version bump to 1.2.10
  * enhance virtual hostname detection.
    If the saphostagent fails to answer the ListInstances query
    additional use the <sid>adm user environment to get the virtual
    hostname.
    (bsc#1237473)
  * support hostnames containing dashes
    (bsc#1233972)
  * remove use of deprecated command crm_master, use crm_attribute
    with option '--promotion' instead
    With that change use '-INFINITY' instead of the short '-inf'
    for the score
  * try to recover lost transient cluster attributes
  * decline promote/takeover, if remote node is still member of the
    cluster but lost his score value.
    Membership check against pacemaker and not against corosync.
  * SAPHanaSR-hookHelper - on action fence, kill hana first to
    avoid call of the srConnectionStatusChanged event which would
    result on SFAIL in some cases
  * remove legacy tools added accidentally
    These tools were designed to work with our classic resource
    agents implementation and will fail on the new implementation
    using different attributes and logic.
  * new man page:
    SAPHanaSR-showAttr_properties.5
  * update man pages:
    SAPHanaSR-angi.7
    SAPHanaSR.7
    SAPHanaSR_basic_cluster.7
    SAPHanaSR-ScaleOut.7
    SAPHanaSR-ScaleOut_basic_cluster.7
    SAPHanaSR_maintenance_examples.7
    SAPHanaSR-angi-scenarios.7
    SAPHanaSR_upgrade_to_angi.7
    ocf_suse_SAPHana.7
    ocf_suse_SAPHanaController.7
    ocf_suse_SAPHanaTopology.7
    SAPHanaSR-alert-fencing.8
    SAPHanaSR-hookHelper.8
    susHanaSR.py.7
    susHanaSrMultiTarget.py.7
    susTkOver.py.7
    susChkSrv.py.7
    SAPHanaSR-showAttr.8
* Wed Nov  6 2024 abriel@suse.com
- Version bump to 1.2.9
  * add SAPHanaSR-alert-fencing, an alert agent for cluster fencing
    alerts.
  * enhance SAPHanaController with the feature ON_FAIL_ACTION=fence
    This is part of the 'FAST-STOP' feature of the resource agents.
    (jsc#SAPSOL-196)
  * Improve handling of timeout return values for the resource
    agents
  * SAPHanaSR-showAttr - adding new option 'sitelist' and new
    output format 'csv' and 'cache'
  * new man page:
    SAPHanaSR-angi-scenarios.7
    SAPHanaSR-alert-fencing.8
  * update man pages:
    SAPHanaSR-angi.7
    SAPHanaSR.7
    SAPHanaSR_basic_cluster.7
    SAPHanaSR-ScaleOut.7
    SAPHanaSR-ScaleOut_basic_cluster.7
    SAPHanaController-scale-up.7
    SAPHanaController-scale-out.7
    SAPHanaTopology.7
    SAPHanaFilesystem.7
    SAPHanaSR_maintenance_examples.7
    SAPHanaSR_upgrade_to_angi.7
    SAPHanaSR-upgrade-to-angi-demo.8
    ocf_suse_SAPHana.7
    ocf_suse_SAPHanaController.7
    ocf_suse_SAPHanaTopology.7
    ocf_suse_SAPHanaFilesystem.7
    susHanaSR.py.7
    susHanaSrMultiTarget.py.7
    susChkSrv.py.7
    susCostOpt.py.7
    SAPHanaSR-showAttr.8
- add additional requires for SLE16
  /usr/bin/sudo and /usr/bin/logger
* Tue May  7 2024 abriel@suse.com
- Version bump to 1.2.7
  * package SAPHanaSR-angi and SAPHanaFilesystem RA are now
    in state 'supported'
    (jsc#PED-6403)
  * add feature HANA 'FAST-STOP' and parameter 'ON_FAIL_ACTION'
    (jsc#SAPSOL-133)
  * new demo script SAPHanaSR-upgrade-to-angi-demo
  * added crm config examples
  * susHanaSR.py adapt syntax
  * Fix the hexdump log for empty node states
  * catch monitor calls for non-cloned resources and report them as
    unsupported instead of 'command not found'
    (bsc#1218333)
  * susChkSrv.py - relocate function logTimestamp()
  * susHanaSR.py - catch possible I/O error
  * security improvements
    (bsc#1218696, bsc#1218698 and bsc#1218699)
  * remove instance parameter "REMOVE_SAP_SOCKETS", no longer
    supported
  * add detailed timing log messages for runtime information
  * add cache/live value optimization
  * new man page:
    SAPHanaSR_upgrade_to_angi.7
    SAPHanaSR-upgrade-to-angi-demo.8
  * update man pages:
    SAPHanaSR.7
    SAPHanaSR-ScaleOut.7
    SAPHanaSR_basic_cluster.7
    SAPHanaSR-ScaleOut_basic_cluster.7
    SAPHanaSR_maintenance_examples.7
    ocf_suse_SAPHana.7
    ocf_suse_SAPHanaController.7
    ocf_suse_SAPHanaFilesystem.7
    susChkSrv.py.7
    susHanaSR.py.7
    susHanaSrMultiTarget.py.7
    SAPHanaSR-manageProvider.8
    SAPHanaSR-showAttr.8
    SAPHanaSR-replay-archive.8
* Fri Dec 15 2023 abriel@suse.com
- Version bump to 1.2.3
  * package is still in status 'technical preview'
  * SAPHanaFilesystem RA has still POC status
  * add parameter 'ON_FAIL_ACTION' to SAPHanaFilesystem RA (POC)
  * improve the usage of SAP virtual hostnames
  * if the susHanaSR.py hook has successfully reported a SR event
    to the cluster a still existing fall-back state file will be
    removed to prevent an override of an already reported
    SR state.
    (bsc#1215693)
  * improve supportability by providing the current process ID of
    the RA, which is logged in the RA outputs, to HANA tracefiles
    too.
    This allows a mapping of the SAP related command invocations
    from the RA and the HANA executions which might have a delay
    in between.
    (bsc#1214613)
  * avoid explicid and implicid usage of /tmp filesystem to keep
    the SAPHanaSR resource agents working even in situations with
    /tmp filesystem full.
    (bsc#1210728)
  * SAPHanaController: change default stop timeout from 3600 to 600
  * SAPHanaController: change default promote timeout from 3600 to
    900
  * try to make set_ and get_hana_attribute function more reliable
    by monitoring the result of the crm_attribute calls
  * fix typo in example srHook/global.ini_susHanaSR
  * fix missing trace section in example srHook/global.ini_susChkSrv
  * update man pages:
    SAPHanaSR-angi.7
    SAPHanaSR.7
    SAPHanaSR-ScaleOut.7
    SAPHanaSR_basic_cluster.7
    SAPHanaSR-ScaleOut_basic_cluster.7
    SAPHanaSR_maintenance_examples.7
    ocf_suse_SAPHana.7
    ocf_suse_SAPHanaController.7
    ocf_suse_SAPHanaTopology.7
    ocf_suse_SAPHanaFilesystem.7
    susChkSrv.py.7
    susHanaSR.py.7
    susTkOver.py.7
    SAPHanaSR-showAttr.8
* Tue Aug  8 2023 fabian.herschel@suse.com
- Version bump to 1.2.0
  * SAPHanaFilesystem RA added (poc status)
* Wed Jul  5 2023 abriel@suse.com
- Version bump to 1.001.5
  * package is still in status 'technical preview'
  * add support for SAPHana ScaleOut environments without standby
    nodes
  * starting to rewrite SAPHanaSR tools from bash to python.
    SAPHanaSR-showAttr and SAPHanaSR-replay-archive
    The name of the tools is not changed by this action, but there
    are some improvements in functionality. See the man pages for
    details.
    The tools SAPHanaSR-monitor and SAPHanaSR-filter are deprecated.
    The classic version of these tools is still shipped in the
    package side-by-side to the rewritten and more powerful
    tools in /usr/bin. Their name is suffixed by '-legacy'.
    The classic version of the tools is deprecated and will be
    removed in a later package update.
* Mon Apr 17 2023 abriel@suse.com
- New package name and new version 1.001.4
  * New package SAPHanaSR-angi
    SAP HANA System Replication - A New Generation Interface
    (jsc#PED-6402)
  * support SAPHana ScaleUp and ScaleOut environments with one
    set of resource agents
- conflicting with the 'old' packages SAPHanaSR and
  SAPHanaSR-ScaleOut
- old changelog entries preserved for history reasons as
  SAPHanaSR-angi is based on all these changes.
* Tue Jan 24 2023 abriel@suse.com
- Version bump to 0.162.1
  * fix for SAPHanaTopology failing with error code 1
    (OCF_ERR_GENERIC) during a normal stop action
    (bsc#1207466)
  * set srhook attribute to PRIM during a probe so that we do not
    need to wait for the first srConnectionChanged() to set the
    attribute
    (bsc#1205535)
* Wed Nov 23 2022 abriel@suse.com
- Version bump to 0.162.0
  * add improvements from SAP to the RA scripts regarding the
    handling of the SAP tools 'HDB version', 'HDBSettings.sh' and
    'pycd' and the SAPHana log filter handling
    (jsc#PED-1739, jsc#PED-2608)
  * fix for SAPHanaSR-monitor reporting "LPA status of one node is
    missing"
    (bsc#1192963, bsc#1203973)
  * SAPHanaSRTools.pm: shows terminate node attribute too
- remove patch:
    0001-bsc-1192963.patch
* Thu Oct  6 2022 varkoly@suse.com
- SAPHanaSR-monitor not reporting correctly
  (bsc#1192963)
  add patch:
    0001-bsc-1192963.patch
* Tue Aug 23 2022 abriel@suse.com
- Version bump to 0.161.1_BF
- add the required 'xmllint' to the package
  (bsc#1201945)
- changes to the demote_clone function of the resource agent:
  if the role is '1:P' (topology agent run into timeouts) the
  function fail with rc=1, to get the managed resource stopped
  changes to the stop_clone function of the topology agent:
  call landscapeHostConfiguration.py and set the roles as they were
  reported. If the command timed out, set the role to '1:P' and
  return 1 to get the node fenced.
  The used timeout for the landscapeHostConfiguration.py call can
  be configured by the cluster action timeout, if needed. It will
  be 50%% of the action timeout or the minimum of 300s.
  (bsc#1198127)
- add new HA/DR provider hook susChkSrv
  (jsc#PED-1241, jsc#PED-1240)
- add new tool SAPHanaSR-manageProvider to show, add and delete
  HA/DR provider sections in the global.ini of SAP HANA.
- update suse icon to new branding
* Wed Jun  1 2022 abriel@suse.com
- Version bump to 0.160.1
- fix HANA_CALL function to support MCOS environments again
  (bsc#1198780)
- fix SAPHanaSR-replay-archive to handle hb_report archives again
  (bsc#1198897)
- add HANA_CALL_TIMEOUT parameter back to the resource agents and
  read the setting from the cluster configuration, if available.
  Defaults to '60'.
  Related to github issue#36
- add new HA/DR provider hook susTkOver
  (jsc#SLE-16347)
- add new hook script for SAP HANA System Replication Scale-Up Cost
  Optimized Scenario.
  (jsc#SLE-18613)
- add a new instance parameter 'REMOVE_SAP_SOCKETS'.
  It is an optional parameter and defaults to 'true'. Now you can
  control, if the RA should remove the unix domain sockets related
  to sapstartsrv before (re-)start sapstartsrv or if it should try
  to adjust the permissions and ownership of these files instead.
* Tue Nov 23 2021 abriel@suse.com
- Version bump to 0.155.0
- Add systemd support for the resource agent to interact with the
  new SAP unit files for sapstartsrv.
  As the new version of the SAP Startup Framework will use systemd
  unit files to control the sapstartsrv process instead of the
  previous used SysV init script, we need to adapt the handling of
  sapstartsrv inside the resource agents to support both ways.
  (bsc#1189530, bsc#1189531)
- The resource start and stop timeout is now configurable by
  increasing the timeout for the action 'start' and/or 'stop'.
  We will use 95%% of this action timeouts to calculate the new
  resource start and stop timeout for the 'WaitforStarted' and
  'WaitforStopped' functions. If the new, calculated timeout value
  is less than '3600', it will be set to '3600', so that we do not
  decrease this timeout by accident
  (bsc#1182545)
- change promotion scoring during maintenance procedure to prevent
  that both sides have an equal promotion scoring after refresh
  which might result in a critical promotion of the secondary.
  (bsc#1174557)
- update of man page SAPHanaSR.py.7 - correct the supported HANA
  version.
  (bsc#1182201)
- if the $hdbState command fails to retrieve the current state of
  the System Replication, the resource agent now uses the
  system_replication/actual_mode attribute (if available) from the
  global.ini file as a fallback.
  This should prevent some confusing and misleading log messages
  during a takeover and solves the problem of a not working
  takeover back (after a successful first takeover)
  (bsc#1181765)
- add dedicated logging of HANA_CALL problems. So it will be now
  possible to identify, if the called hana command or the needed
  su command throws the error and for further hints we log the
  stderr output.
  Additional it is possible to get regular log messages for the
  used commands, their return code and their stderr output by
  enabling the 'debug' mode of the resource agents.
  (bsc#1182774)
* Thu Jul  2 2020 abriel@suse.com
- Version bump to 0.154.1
- log empty site names, but do not generate bad formatted cluster
  attribute name
  (bsc#1173581)
- fix documentation of some parameter defaults
- adjust start/stop/promote/monitor action timeouts to match
  official recommendations
* Thu Nov 21 2019 abriel@suse.com
- restart sapstartsrv service on master nameserver node during
  monitor action, if needed. But NOT during probes.
  (bsc#1157453)
* Fri Nov 15 2019 abriel@suse.com
- Version bump to 0.154.0
- restart sapstartsrv service on master nameserver node
  (bsc#1156150)
* Fri Nov  8 2019 abriel@suse.com
- Version bump to 0.153.3
- The SAPHana resource agent must not down-score a SAP HANA
  Database site, if the landscape status is still 2, which means
  warning.
  Keep high scoring during recovery of the master name server.
  Use a fall-back scoring for the master nameserver nodes, if the
  current roles of the node(s) got lost.
  (bsc#1156067)
- change the shebang line of the HAWK2 templates to python3
  (bsc#1155423)
* Wed Sep 11 2019 abriel@suse.com
- fix typo in a condition statement (bnc#1149829)
* Fri Aug 30 2019 abriel@suse.com
- Version bump to 0.153.2
- rescore the master and fix some log string literals
- Fix bsc#1133866:
  Return $OCF_RUNNING_MASTER (8) instead of $OCF_SUCCESS (0) when
  probing a promoted node.
- If the SAP HANA CALL to 'landscapeHostConfiguration.py' is
  running into a timeout, do a retry of the command. If it still
  fails with a timeout, raise an error but do not set attributes
  to prevent unlogged failovers because of empty or unknown
  attributes.
  (bsc#1134106, bsc#1133024, bsc#1101373)
- Fix bsc#1082974:
  set attribute for remoteNode
- Fix bsc#1139715:
  Using crm-attributes written by a SAP HANA SR provider hook does
  improve the data integrity in special error conditions with
  multiple errors coming in a short time frame.
  Stabilized remote-site detection; SAPHana could now use a site
  specific SR cluster attribute which could be set by a SAP HA/DR
  provider call.
  Add a HA/DR provider hook script, config implementation and man
  page.
  Add parameter "HANA_CALL_TIMEOUT" to the RA configuration
  (SAPHanaTopology and SAPHanaSR) to set a timeout for HANA calls
  like landscapeHostConfiguration.py.
  Implemented "reload" method to allow changing parameters like
  "AUTOMATED_REGISTER"
  Set SWAIT during startup, but only if the attribute is already set
  Set PRIM after promote, but only if the attribute is already set
  The promote function has to set the return code according to the
  checks of the takeover result
  New tool SAPHanaSR-replay-archive, SAPHanaSR-filter and
  SAPHanaSR-showAttr to support SITE attributes
* Fri May 18 2018 imanyugin@suse.com
- Version bump to 0.152.22
- Fix bsc#1091074:
    + Adjust Perl scripts to Perl 5.26.0
    + Remove show_SAPHanaSR_attributes
    + The user is advised to use SAPHanaSR-showAttr instead
- SAPHanaTopology: stricter match for system replication 'mode' in awk
* Wed Jan 31 2018 ro@suse.de
- remove duplicate BuildArch line from specfile
* Mon Nov 20 2017 imanyugin@suse.com
- FATE#323526: adjust HAWK2 Wizards to run on both Python 2 and 3
* Mon Oct 23 2017 imanyugin@suse.com
- Fix bsc#1062267: SAPHanaSR wizard sets IPAddr2 agent's NIC to eth0
* Thu Jul  6 2017 imanyugin@suse.com
- Fix bsc#1045606: update man pages
* Fri Jun  2 2017 imanyugin@suse.com
- Fix bsc#1042154: Scoring race condition between SAPHanaTopology and SAPHana
* Fri May 26 2017 imanyugin@suse.com
- Version bump to 0.152.21
* Wed May  3 2017 imanyugin@suse.com
- Fix bsc#1034685: SAPHanaTopology fails once after updating to 0.152.20
* Wed Feb 15 2017 imanyugin@suse.com
- Version bump to 0.152.20
- Fix bsc#1019117: Fix master scoring of secondary during a takeover
* Tue Dec 20 2016 ilya.manyugin@suse.com
- Version bump to 0.152.19
- Fix bsc#1014397: SAPHanaSR not failing over consistently
- Fix bsc#1008469: SAPHanaSR-monitor reports wrong status colors and error messages
- Add a cluster attribute hana_<SID>_version upon a probe of SAPHanaTopology
- Update man pages
- Change the Setup Guide to contain just the URL to the best practices
- Fix bsc#994753: Tool SAPHanaSR-showAttr fails to read offline cib file correctly
- Fix bsc#1016691: Status file of SAPHanaTopology is not multi instance aware (MCOS)
- Fix bsc#1016936: SAPHanaSR-TestDriver fails to detect the correct status
- Fix bsc#985822: HAWK Wizards are listed as legacy
* Wed Nov  2 2016 imanyugin@suse.com
- Version bump to 0.152.18
- Fix bsc#985474: SAPHanaSR-showAttr shows node ID instead of uname
- Fix bsc#1007825: SAPHanaSR-showAttr fails to show node status
- Fix bsc#1005872: SAPHana Resource Agent handling virtual hostnames
- Fix bsc#1007605: SAPHanaSR no longer ignores DR SR status
* Wed Jun  1 2016 fabian.herschel@suse.com
- bsc#982355 - SAPHanaSR: SAP changed the interface of landscapeHostConfiguration.py beginning with SPS12 rev 120
- bsc#981446 - SAPHanaSR: SAP revokes interface hdbnsutil -sr_state beginning from rev 112.03
* Tue May  3 2016 fabian.herschel@suse.com
- log_attributes are not longer logged to /var/log/fhATTRIBUTES by default
* Fri Apr 29 2016 fabian.herschel@suse.com
- bsc#977644 -  SAPHanaSR: SAP Hana resource with Virtual IP not migrating from master to secondary node correctly
* Tue Nov 24 2015 fabian.herschel@suse.com
- Fix for bsc#954653; SAPHanaSR: Resources SAPHana and SAPHanaTopology not managed correctly by Hawk in SLES12 for SAP
- Use new parameters for hdbnsutil -sr_regsiter for SAP HANA >= SPS110
* Thu Oct  8 2015 fabian.herschel@suse.com
- Fix for bsc#949544; SAPHanaSR needs to handle hanging SAP HANA calls
* Mon Oct  5 2015 fabian.herschel@suse.com
- Fix for bsc#947303; SAPHanaSR: SAPHana resource agent still requires secure store users
* Thu Aug 20 2015 fabian.herschel@suse.com
- Avoid to set local lpt, if accidently the remote host name is empty
* Wed Jul 22 2015 fabian.herschel@suse.com
- Fix for bsc#939039; SAPHanaSR fails to detect remote site name if site names are substring of an other remote site name like SLE and SLEDR
* Tue Jul 14 2015 fabian.herschel@suse.com
- Updated the package version to 0.151 to relfect matching the upstream version
* Mon Jun 29 2015 fabian.herschel@suse.com
- Fix for bsc#935755; SAPHanaSR together with DAA-SAP-Instance does not work as expected
- Fix for bsc#936387; SAPHanaSR fails to work with multi tenant databases
- Fix for bsc#919925; SAPHanaSR: Leaving Node Maintenance stops HANA Resource Agent
* Mon Dec  8 2014 fabian.herschel@suse.com
- Fix for bsc#908861; SAPHanaSR should be tolerant to an additional secondary
  Still only ONE SAPHANA SID in SR per cluster, still two nodes only but
  an additional secondary in a chain (like A=>B->C) could now be ignored
* Tue Nov  4 2014 fabian.herschel@suse.com
- Package version 0.149;
- Fix for bnc#902244; SAPHanaSR fails when hdbnsutil does not return correctly or does report incomplete output
- Fix for bnc#902241; SAPHanaSR fails in cold bootstrap
- Updated Setup-Guide 11/04/2014
* Fri Jun 13 2014 fabian.herschel@suse.com
- Fix for bnc#882474; SAPHanaSR: SAPHanaTopology could now handle broken saphostexec
* Wed Jun  4 2014 fabian.herschel@suse.com
- Package version 0.148; Fate 317181 Resource Agents for SAP HANA System Replication
